Learn R Programming

Qploidy (version 1.0.1)

get_aneuploids: indexes for aneuploids

Description

indexes for aneuploids

Usage

get_aneuploids(ploidy_df)

Value

A logical vector where each element corresponds to an individual in the input ploidy table. The value is `TRUE` if the individual is identified as potentially aneuploid, and `FALSE` otherwise.

Arguments

ploidy_df

ploidy table (chromosome in columns and individuals in rows)