Learn R Programming

Qploidy (version 1.0.1)

get_baf_par: To create baf in parallel

Description

To create baf in parallel

Usage

get_baf_par(par_all_item, ploidy = 2)

Value

A list of numeric vectors, where each vector contains the BAF values for a corresponding row in the input `par_all_item` matrices. Each BAF vector has values ranging from 0 to 1, representing the standardized allelic ratios for the respective samples or markers.

Arguments

par_all_item

list containing R and theta matrices, and clusters models

ploidy

integer defining ploidy