Learn R Programming

Qploidy (version 1.0.1)

merge_arms_format: Merges chromosome-arm level analysis results into chromosome level format

Description

Merges chromosome-arm level analysis results into chromosome level format

Usage

merge_arms_format(x, filter_diff = NULL)

Value

An updated object of class `qploidy_area_ploidy_estimation` with the following modifications:

- `ploidy`: A matrix where chromosome-arm level results are merged into chromosome-level format. If `filter_diff` is provided, ploidy values with differences below the threshold are set to `NA`.

The structure of the returned object remains consistent with the input, but with updated ploidy information.

Arguments

x

object of class qploidy_area_ploidy_estimation

filter_diff

filter by difference on area proportion between first and second place