pascalTriangle: Pascal Triangle for Expected Peaks Calculation

View source: R/utils.R

pascalTriangleR Documentation

Pascal Triangle for Expected Peaks Calculation

Description

This function generates the Pascal triangle for a given ploidy value. The Pascal triangle is used to define the expected peaks for each ploidy level, which can be useful in various genetic analyses.

Usage

pascalTriangle(h)

Arguments

h

An integer representing the ploidy value.

Value

A list where each element corresponds to a row of the Pascal triangle, up to the specified ploidy value.


Qploidy documentation built on July 11, 2026, 5:06 p.m.