This function converts a VCF file into a format compatible with Qploidy analysis. It extracts genotype and allele depth information and formats it into a data frame.
qploidy_read_vcf(vcf_file, geno = FALSE, geno.pos = FALSE)A data frame containing the processed VCF data.
Path to the VCF file.
Logical. If TRUE, the output columns will include MarkerName, SampleName, geno, and prob. If FALSE, the output will include MarkerName, SampleName, X, Y, R, and ratio.
Logical. If TRUE, the output will include MarkerName, Chromosome, and Position columns.