write_qploidy_standardization: Write Qploidy Standardization Object to File

View source: R/standardization.R

write_qploidy_standardizationR Documentation

Write Qploidy Standardization Object to File

Description

This function writes a 'qploidy_standardization' object to a specified file. The output file includes metadata, filtering information, and the standardized dataset.

Usage

write_qploidy_standardization(qploidy_standardization_object, out_filename)

Arguments

qploidy_standardization_object

An object of class 'qploidy_standardization' to be written to file.

out_filename

A string specifying the path to the output file where the data will be saved. Specify in the file name the desired extension (e.g., 'my_output.csv').

Value

None. The function writes the data to the specified file.


Qploidy documentation built on July 11, 2026, 5:06 p.m.