clean_summary: Clean Axiom Summary File
Description
This function removes consecutive A allele probes from an Axiom summary
file.
Usage
clean_summary(summary_df)
Value
A list with cleaned A and B probes.
Arguments
- summary_df
A data frame containing A and B probe intensities.