This function calculates R and theta values from a cleaned summary file. It optionally performs standard normalization by plate and markers.
get_R_theta(cleaned_summary, atan = FALSE)A list containing the following elements: - `R_all`: A data frame where each row corresponds to a marker, and columns represent total signal intensity (R) values for each sample. - `theta_all`: A data frame where each row corresponds to a marker, and columns represent allelic ratio (theta) values for each sample. - Both data frames include a `MarkerName` column as the first column, which contains marker identifiers.
A summary object from the clean_summary function.
Logical. If TRUE, calculates theta using atan2.