To create baf in parallel
get_baf_par(par_all_item, ploidy = 2)A list of numeric vectors, where each vector contains the BAF values for a corresponding row in the input `par_all_item` matrices. Each BAF vector has values ranging from 0 to 1, representing the standardized allelic ratios for the respective samples or markers.
list containing R and theta matrices, and clusters models
integer defining ploidy