| is_compressed_file | R Documentation |
This function checks whether a given file is compressed by inspecting its magic number (first few bytes). It detects common compression formats such as gzip ('.gz'), bzip2 ('.bz2'), and xz ('.xz').
is_compressed_file(file_path)
file_path |
A character string giving the path to the file to be checked. |
A character string indicating the compression type ('"gzip (.gz)"', '"bzip2 (.bz2)"', or '"xz (.xz)"') if the file is compressed, or 'FALSE' if the file is not recognized as compressed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.