Merges chromosome-arm level analysis results into chromosome level format
merge_arms_format(x, filter_diff = NULL)An updated object of class `qploidy_area_ploidy_estimation` with the following modifications:
- `ploidy`: A matrix where chromosome-arm level results are merged into chromosome-level format. If `filter_diff` is provided, ploidy values with differences below the threshold are set to `NA`.
The structure of the returned object remains consistent with the input, but with updated ploidy information.
object of class qploidy_area_ploidy_estimation
filter by difference on area proportion between first and second place