View source: R/simulate_inputs.R
| simulate_axiom_summary | R Documentation |
This function generates a simulated Axiom array summary file with probe IDs ending in '-A' or '-B' and sample intensities. The intensities are simulated based on the genotype of the sample: homozygous for A, homozygous for B, or heterozygous.
simulate_axiom_summary(file_path, n_probes = 100, n_samples = 10, seed)
file_path |
The path where the simulated summary file will be saved. |
n_probes |
Number of probes to simulate. Default is 100. |
n_samples |
Number of samples to simulate. Default is 10. |
seed |
The seed for random number generation to ensure reproducibility. |
None. The function writes the simulated summary content to the specified file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.