View source: R/standardization.R
| write_qploidy_standardization | R Documentation |
This function writes a 'qploidy_standardization' object to a specified file. The output file includes metadata, filtering information, and the standardized dataset.
write_qploidy_standardization(qploidy_standardization_object, out_filename)
qploidy_standardization_object |
An object of class 'qploidy_standardization' to be written to file. |
out_filename |
A string specifying the path to the output file where the data will be saved. Specify in the file name the desired extension (e.g., 'my_output.csv'). |
None. The function writes the data to the specified file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.